==> leonardo-0.4.0.tgz: leonardo-0.4.0/lib/templates/draft.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

draft_initial_form_content = "Enter content of new page here."

draft_existing_title = "Page with that title already exists in drafts."

draft_no_title = "Please provide a title."

draft_success = "Successfully created '%(draft_resource_id)s'."

draft_title = "Drafts"

draft_item = """
<li><a href="%(draft_link)s">%(draft_title)s</a></li>
"""

draft_list = """
<ul>
%(draft_items)s
</ul>
"""

empty_draft_list = """
<p>No drafts.</p>
"""

draft_page = """
<p>%(status)s</p>
            
<h2>Drafts</h2>
           
<h3>Existing</h3>
%(draft_list)s

<h3>New Draft Page</h3>
<form action="%(action)s" method="POST">
  Page Title: <input type="text" name="%(page_title_name)s" value="page_title"/>
  <br />
  <textarea name="%(page_content_name)s" rows="25" cols="80">%(form_content)s</textarea>
  <br />
  <input type="submit" value="submit"/>
</form>
<a href="%(action)s">Cancel</a>
"""

draft_menu = """
<p><a href="%(draft_href)s")>Drafts</a><p>
"""

draft_post_to_wiki_form = """
<form action="%(post_action)s" method="post">
<p>
<input type="hidden" name="%(resource_name)s" value="%(resource_id_to_put)s" />
<input type="hidden" name="%(page_content_name)s" value="%(page_content)s" />
<input type="submit" value="post" /> to %(resource_id_to_put)s
</p>
</form>
"""

draft_post_to_blog_form = """
<form action="%(post_action)s" method="post">
<p>
<input type="hidden" name="%(resource_name)s" value="%(resource_id_to_put)s" />
<input type="hidden" name="%(page_content_name)s" value="%(page_content)s" />
<input type="submit" value="post" /> to %(resource_id_to_put)s
</p>
</form>
"""

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/templates/draft.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

draft_initial_form_content = "==Heading==\n\nType content here."

draft_existing_title = "Page with that title already exists in drafts."

draft_no_title = "Please provide a title."

draft_success = "Successfully created '%(draft_resource_id)s'."

draft_title = "Drafts"

draft_item = """
<li><a href="%(draft_link)s">%(draft_title)s</a></li>
"""

draft_list = """
<ul>
%(draft_items)s
</ul>
"""

empty_draft_list = """
<p>No drafts.</p>
"""

draft_page = """
<p>%(status)s</p>
            
<h2>Drafts</h2>
           
<h3>Existing</h3>
%(draft_list)s

<h3>New Draft Page</h3>
<form action="%(action)s" method="POST">
  <textarea name="%(page_content_name)s" rows="25" cols="80">%(form_content)s</textarea>
  <br />
  <input type="hidden" name="%(page_content_type_name)s" value="%(page_content_type)s">
  <input type="submit" value="submit"/> as %(page_content_type)s.
</form>
<a href="%(action)s">Cancel</a>
"""

draft_menu = """
<p><a href="%(draft_href)s")>Drafts</a><p>
"""

draft_put_form = """
<form action="%(post_action)s" method="post">
<p>
<input type="hidden" name="%(page_content_name)s" value="%(page_content)s" />
<input type="hidden" name="%(page_content_type_name)s" value="%(page_content_type)s" />
<input type="submit" value="PUT" /> to <input type="text" name="%(resource_name)s" value="%(resource_id_to_put)s" />
 as %(page_content_type)s.
</p>
</form>
"""
